class Constant(object):
    MULTIPLE_COMENT_START_SYMBOL = '/*'
    MULTIPLE_COMENT_END_SYMBOL = '*/'
    SINGLE_COMMENT_SYMBOL = '//'
    BRACE_LEFT = '{'
    BRACE_RIGHT = '}'
    EQUAL_SIGN = '='
    SEMICOLON = ';'
    ANGLE_BRACKET_LEFT = '<'
    ANGLE_BRACKET_RIGHT = '>'
